Pipeline

Struct Pipeline 

pub struct Pipeline { /* private fields */ }
A builder for creating command pipelines.

Example

use bare_script::sync::Pipeline;

#[cfg(not(windows))]
{
let output = Pipeline::new("echo")
    .arg("hello world")
    .pipe("grep")
    .arg("hello")
    .execute();
     
assert!(output.is_ok());
}

Implementations

Source

impl Pipeline

pub fn new<S: AsRef<OsStr>>(program: S) -> Self

Creates a new pipeline starting with the specified program.

pub fn arg<S: AsRef<OsStr>>(self, arg: S) -> Self

Adds an argument to the last command in the pipeline.

pub fn args<I, S>(self, args: I) -> Self
where I: IntoIterator<Item = S>, S: AsRef<OsStr>,

Adds multiple arguments to the last command in the pipeline.

pub fn pipe<S: AsRef<OsStr>>(self, program: S) -> Self

Adds a new command to the pipeline, piping the output of the previous command to the stdin of this command.

Errors

Returns an error if the previous command’s stdout could not be configured for piping.

pub fn env<K, V>(self, key: K, value: V) -> Self
where K: AsRef<OsStr>, V: AsRef<OsStr>,

Sets an environment variable for all commands in the pipeline.

pub fn current_dir<D>(self, dir: D) -> Self
where D: AsRef<Path>,

Sets the working directory for all commands in the pipeline.

pub fn capture_output(self) -> Self

Configures the pipeline to capture the final output.

This must be called before execute() to capture stdout/stderr.

pub fn execute(&mut self) -> ScriptResult<Output>

Executes the pipeline and returns the output of the final command.

Errors

Returns an error if any command in the pipeline fails to execute.